@@ -13,7 +13,7 @@ from unstructured_ingest.embed.interfaces import (
     BaseEmbeddingEncoder,
     EmbeddingConfig,
 )
-from unstructured_ingest.errors_v2 import (
+from unstructured_ingest.error import (
     ProviderError,
     RateLimitError,
     UserAuthError,
@@ -27,12 +27,24 @@ if TYPE_CHECKING:
     from botocore.client import BaseClient
 
     class BedrockRuntimeClient(BaseClient):
-        def invoke_model(self, body: str, modelId: str, accept: str, contentType: str) -> dict:
+        def invoke_model(
+            self,
+            body: str,
+            modelId: str,
+            accept: str,
+            contentType: str,
+            inferenceProfileId: str = None,
+        ) -> dict:
             pass
 
     class AsyncBedrockRuntimeClient(BaseClient):
         async def invoke_model(
-            self, body: str, modelId: str, accept: str, contentType: str
+            self,
+            body: str,
+            modelId: str,
+            accept: str,
+            contentType: str,
+            inferenceProfileId: str = None,
         ) -> dict:
             pass
 
@@ -58,14 +70,31 @@ def conform_query(query: str, provider: str) -> dict:
 
 
 class BedrockEmbeddingConfig(EmbeddingConfig):
-    aws_access_key_id: SecretStr = Field(description="aws access key id")
-    aws_secret_access_key: SecretStr = Field(description="aws secret access key")
-    region_name: str = Field(description="aws region name", default="us-west-2")
+    aws_access_key_id: SecretStr | None = Field(description="aws access key id", default=None)
+    aws_secret_access_key: SecretStr | None = Field(
+        description="aws secret access key", default=None
+    )
+    region_name: str = Field(
+        description="aws region name",
+        default_factory=lambda: (
+            os.getenv("BEDROCK_REGION_NAME") or
+            os.getenv("AWS_DEFAULT_REGION") or
+            "us-west-2"
+        )
+    )
+    endpoint_url: str | None = Field(description="custom bedrock endpoint url", default=None)
+    access_method: str = Field(
+        description="authentication method", default="credentials"
+    )  # "credentials" or "iam"
     embedder_model_name: str = Field(
         default="amazon.titan-embed-text-v1",
         alias="model_name",
         description="AWS Bedrock model name",
     )
+    inference_profile_id: str | None = Field(
+        description="AWS Bedrock inference profile ID",
+        default_factory=lambda: os.getenv("BEDROCK_INFERENCE_PROFILE_ID"),
+    )
 
     def wrap_error(self, e: Exception) -> Exception:
         if is_internal_error(e=e):
@@ -96,6 +125,20 @@ class BedrockEmbeddingConfig(EmbeddingConfig):
         return e
 
     def run_precheck(self) -> None:
+        # Validate access method and credentials configuration
+        if self.access_method == "credentials":
+            if not (self.aws_access_key_id and self.aws_secret_access_key):
+                raise ValueError(
+                    "Credentials access method requires aws_access_key_id and aws_secret_access_key"
+                )
+        elif self.access_method == "iam":
+            # For IAM, credentials are handled by AWS SDK
+            pass
+        else:
+            raise ValueError(
+                f"Invalid access_method: {self.access_method}. Must be 'credentials' or 'iam'"
+            )
+            
         client = self.get_bedrock_client()
         try:
             model_info = client.list_foundation_models(byOutputModality="EMBEDDING")
@@ -113,11 +156,30 @@ class BedrockEmbeddingConfig(EmbeddingConfig):
             raise self.wrap_error(e=e)
 
     def get_client_kwargs(self) -> dict:
-        return {
-            "aws_access_key_id": self.aws_access_key_id.get_secret_value(),
-            "aws_secret_access_key": self.aws_secret_access_key.get_secret_value(),
+        kwargs = {
             "region_name": self.region_name,
         }
+        
+        if self.endpoint_url:
+            kwargs["endpoint_url"] = self.endpoint_url
+            
+        if self.access_method == "credentials":
+            if self.aws_access_key_id and self.aws_secret_access_key:
+                kwargs["aws_access_key_id"] = self.aws_access_key_id.get_secret_value()
+                kwargs["aws_secret_access_key"] = self.aws_secret_access_key.get_secret_value()
+            else:
+                raise ValueError(
+                    "Credentials access method requires aws_access_key_id and aws_secret_access_key"
+                )
+        elif self.access_method == "iam":
+            # For IAM, boto3 will use default credential chain (IAM roles, environment, etc.)
+            pass
+        else:
+            raise ValueError(
+                f"Invalid access_method: {self.access_method}. Must be 'credentials' or 'iam'"
+            )
+            
+        return kwargs
 
     @requires_dependencies(
         ["boto3"],
@@ -172,12 +234,18 @@ class BedrockEmbeddingEncoder(BaseEmbeddingEncoder):
         bedrock_client = self.config.get_client()
         # invoke bedrock API
         try:
-            response = bedrock_client.invoke_model(
-                body=json.dumps(body),
-                modelId=self.config.embedder_model_name,
-                accept="application/json",
-                contentType="application/json",
-            )
+            invoke_params = {
+                "body": json.dumps(body),
+                "modelId": self.config.embedder_model_name,
+                "accept": "application/json",
+                "contentType": "application/json",
+            }
+
+            # Add inference profile if configured
+            if self.config.inference_profile_id:
+                invoke_params["inferenceProfileId"] = self.config.inference_profile_id
+
+            response = bedrock_client.invoke_model(**invoke_params)
         except Exception as e:
             raise self.wrap_error(e=e)
 
@@ -218,12 +286,18 @@ class AsyncBedrockEmbeddingEncoder(AsyncBaseEmbeddingEncoder):
             async with self.config.get_async_client() as bedrock_client:
                 # invoke bedrock API
                 try:
-                    response = await bedrock_client.invoke_model(
-                        body=json.dumps(body),
-                        modelId=self.config.embedder_model_name,
-                        accept="application/json",
-                        contentType="application/json",
-                    )
+                    invoke_params = {
+                        "body": json.dumps(body),
+                        "modelId": self.config.embedder_model_name,
+                        "accept": "application/json",
+                        "contentType": "application/json",
+                    }
+
+                    # Add inference profile if configured
+                    if self.config.inference_profile_id:
+                        invoke_params["inferenceProfileId"] = self.config.inference_profile_id
+
+                    response = await bedrock_client.invoke_model(**invoke_params)
                 except Exception as e:
                     raise self.wrap_error(e=e)
                 async with response.get("body") as client_response:
