@@ -11,8 +11,12 @@ from unstructured_ingest.data_types.file_data import (
     FileDataSourceMetadata,
     SourceIdentifiers,
 )
-from unstructured_ingest.error import SourceConnectionError
-from unstructured_ingest.errors_v2 import UserAuthError, UserError
+from unstructured_ingest.error import (
+    SourceConnectionError,
+    UserAuthError,
+    UserError,
+    ValueError,
+)
 from unstructured_ingest.interfaces import (
     AccessConfig,
     ConnectionConfig,
