@@ -9,7 +9,7 @@ from unstructured_ingest.data_types.file_data import (
     FileDataSourceMetadata,
     SourceIdentifiers,
 )
-from unstructured_ingest.error import SourceConnectionError
+from unstructured_ingest.error import UserAuthError, ValueError
 from unstructured_ingest.interfaces import (
     AccessConfig,
     ConnectionConfig,
@@ -70,9 +70,9 @@ class DiscordIndexer(Indexer):
 
     def precheck(self) -> None:
         if not self.connection_config.access_config.get_secret_value().token:
-            raise SourceConnectionError("Discord token is missing")
+            raise UserAuthError("Discord token is missing")
         if not self.index_config.channels:
-            raise SourceConnectionError("No channels provided")
+            raise ValueError("No channels provided")
 
     def get_channel_file_data(self, channel_id: str) -> Optional[FileData]:
         # Fetch channel metadata
