@@ -19,6 +19,7 @@ from unstructured_ingest.error import (
     DestinationConnectionError,
     SourceConnectionError,
     SourceConnectionNetworkError,
+    UnstructuredIngestError,
 )
 from unstructured_ingest.interfaces import (
     AccessConfig,
@@ -440,10 +441,10 @@ class ElasticsearchUploader(Uploader):
                     logger.error(
                         f"Batch upload failed - {e} - with following errors: {sanitized_errors}"
                     )
-                    raise e
+                    raise DestinationConnectionError(str(e))
                 except Exception as e:
                     logger.error(f"Batch upload failed - {e}")
-                    raise e
+                    raise UnstructuredIngestError(str(e))
 
     def _sanitize_bulk_index_error(self, error: dict[str, dict]) -> dict:
         """Remove data uploaded to index from the log, leave only error information.
