@@ -19,8 +19,9 @@ from unstructured_ingest.error import (
     DestinationConnectionError,
     SourceConnectionError,
     SourceConnectionNetworkError,
+    UserAuthError,
+    ValueError,
 )
-from unstructured_ingest.errors_v2 import UserAuthError
 from unstructured_ingest.interfaces import (
     AccessConfig,
     ConnectionConfig,
