@@ -25,7 +25,12 @@ from unstructured_ingest.data_types.file_data import (
     FileDataSourceMetadata,
     SourceIdentifiers,
 )
-from unstructured_ingest.error import SourceConnectionError, SourceConnectionNetworkError
+from unstructured_ingest.error import (
+    MissingCategoryError,
+    SourceConnectionError,
+    SourceConnectionNetworkError,
+    ValueError,
+)
 from unstructured_ingest.interfaces import (
     AccessConfig,
     ConnectionConfig,
@@ -41,11 +46,6 @@ from unstructured_ingest.processes.connector_registry import (
 )
 from unstructured_ingest.utils.dep_check import requires_dependencies
 
-
-class MissingCategoryError(Exception):
-    """There are no categories with that name."""
-
-
 CONNECTOR_TYPE = "salesforce"
 
 if TYPE_CHECKING:
